(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     25507,        672]
NotebookOptionsPosition[     21916,        617]
NotebookOutlinePosition[     22470,        638]
CellTagsIndexPosition[     22427,        635]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Chapter 3, Section 3.7", "Section",ExpressionUUID->"91b05445-c52f-4009-bd5e-44984d393a60"],

Cell[TextData[{
 "Here we define a general function, ",
 StyleBox["Stability", "Input"],
 ", that (i) calculates the location of the specified equilibrium point \
(given by ",
 StyleBox["ptid", "Input"],
 ") for the given mass ratio ",
 StyleBox["\[Mu]", "Input"],
 ", (ii) calculates the eigenvalues of the displaced system and (iii) \
calculates the solution describing the motion around the equilibrium point \
for a displacement ",
 StyleBox["(X0,Y0)", "Input"],
 ".  The function uses most of the code from ",
 StyleBox["Location", "Input"],
 " (see ",
 StyleBox["Fig.3.7.nb",
  FontWeight->"Bold"],
 ") to calculate the position of the equilibrium point."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a2dd74a2-23ad-4b70-a9ff-8c1d2c4e6166"],

Cell["\<\
Stability[\[Mu]_, ptid_Integer, {X0_, Y0_}] :=
Module[{\[Alpha], r1, r2, \[Mu]1=1-\[Mu], \[Mu]2=\[Mu], lageq},
If[ptid\[Equal]1,y=0;
  \[Alpha]=(\[Mu]/(3*(1-\[Mu])))^(1/3);
  r20=\[Alpha]-(1/3)*\[Alpha]^2-(1/9)*\[Alpha]^3;
  lageq=\[Mu]1*(1-r2-1/(1-r2)^2)-\[Mu]2*(r2-1/r2^2);
  r2=r2/.FindRoot[lageq\[Equal]0,{r2,r20}];
  r1=1-r2;
  x=\[Mu]1-r2];
If[ptid\[Equal]2,y=0;
  \[Alpha]=(\[Mu]/(3*(1-\[Mu])))^(1/3);
  r20=\[Alpha]+(1/3)*\[Alpha]^2-(1/9)*\[Alpha]^3;
  lageq=\[Mu]1*(1+r2-1/(1+r2)^2)+\[Mu]2*(r2-1/r2^2);
  r2=r2/.FindRoot[lageq\[Equal]0,{r2,r20}];
  r1=1+r2;
  x=\[Mu]1+r2];
If[ptid\[Equal]3,y=0;
  \[Beta]=-(7/12)*(\[Mu]2/\[Mu]1)+(7/12)*(\[Mu]2/\[Mu]1)^2;
  r10=1+\[Beta];
  lageq=\[Mu]1*(r1-1/r1^2)+\[Mu]2*(1+r1-1/(1+r1)^2);
  r1=r1/.FindRoot[lageq\[Equal]0,{r1,r10}];
  r2=1+r1; x=-r1-\[Mu]2];
If[ptid\[Equal]4,x=1/2-\[Mu]2;
  y=N[Sqrt[3]/2];
  r1=1;
  r2=1];
If[ptid\[Equal]5,x=1/2-\[Mu]2;
    y=N[-Sqrt[3]/2];
    r1=1;
    r2=1];
Print[\"Mass ratio = \", \[Mu],\"\\n\"];
Print[\"Lagrangian Point \", ptid,\"\\n\"];
Print[\"{x0, y0} = \", {x,y},\"\\n\"];
If[ptid == 1 || ptid == 2 || ptid ==3,
   abar = (1-\[Mu])/r1^3 + \[Mu]/r2^3;
   ceqq = \[Lambda]^4 + (2-abar)*\[Lambda]^2 + (1+abar-2*abar^2);
   soln = Chop[\[Lambda] /. NSolve[ceqq == 0, {\[Lambda]}]]];
If[ptid == 4 || ptid == 5,
   ceqq = \[Lambda]^4 + \[Lambda]^2 + (27/4)*\[Mu]2*(1-\[Mu]2);
   soln = Chop[\[Lambda] /. NSolve[ceqq == 0, {\[Lambda]}]]];
abar = \[Mu]1/r1^3 + \[Mu]2/r2^3;
cbar = 3*(\[Mu]1*(x+\[Mu]2)/r1^5 + \[Mu]2*(x-\[Mu]1)/r2^5)*y;
dbar = 3*(\[Mu]1*(x+\[Mu]2)^2/r1^5 + \[Mu]2*(x-\[Mu]1)^2/r2^5);
uxx = 1 - abar + dbar;
uxy = cbar;
Print[\"Eigenvalues :\"];
Print[ColumnForm[soln],\"\\n\"];
Do[s[i] = soln[[i]], {i,1,4}];
Do[b[i] = (s[i]^2 - uxx)*a[i]/(2*s[i] + uxy), {i,1,4}];
eq1 = a[1] + a[2] + a[3] + a[4] == X0;
eq2 = b[1] + b[2] + b[3] + b[4] == Y0;
eq3 = s[1]*a[1] + s[2]*a[2] + s[3]*a[3] + s[4]*a[4] == 0;
eq4 = s[1]*b[1] + s[2]*b[2] + s[3]*b[3] + s[4]*b[4] == 0;
sol = Flatten[Chop[NSolve[
         {eq1,eq2,eq3,eq4},{a[1], a[2], a[3], a[4]}]]];
asol = {a[1], a[2], a[3], a[4]} /. sol;
bsol = {b[1], b[2], b[3], b[4]} /. sol;
Print[\"\\nValues of \[Alpha] bar: \"];
Print[ColumnForm[asol]];
Print[\"\\nValues of \[Beta] bar: \"];
Print[ColumnForm[bsol]];
xx[t_] := 
Chop[ComplexExpand[
 ({a[1], a[2], a[3], a[4]} . 
    {Exp[s[1]*t], Exp[s[2]*t], Exp[s[3]*t], Exp[s[4]*t]}) /.
sol]];
yy[t_] := 
Chop[ComplexExpand[
 ({b[1], b[2], b[3], b[4]} . 
    {Exp[s[1]*t], Exp[s[2]*t], Exp[s[3]*t], Exp[s[4]*t]}) /.
sol]];
Print[\"\\nX(t) = \"];
Print[Chop[xx[t]]];
Print[\"\\nY(t) = \"];
Print[Chop[yy[t]],\"\\n\"]
]\
\>", "Input",
 CellChangeTimes->{{3.811167086505834*^9, 3.811167105659904*^9}, {
  3.811167160034439*^9, 3.811167171316059*^9}, {3.8111672029783707`*^9, 
  3.811167215112831*^9}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[1]:=",ExpressionUUID->"4e73d262-3ac7-4d62-920c-b57f37a4ee71"],

Cell["\<\
We consider two examples corresponding to the solutions given in Sect.3.7.1 \
and Sect.3.7.2 respectively.  In the first we examine the stability of the L1 \
point for a mass ratio \[Mu]=0.01 and small displacement of (0.00001,0.00001) \
from the equilibrium point.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"6a3b16f9-ce5c-4575-b76e-fd643a793d2f"],

Cell[CellGroupData[{

Cell["Stability[0.01, 1, {0.00001,0.00001}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[2]:=",ExpressionUUID->"6ff58bb2-071a-4adc-aae2-4db1ae0d6831"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mass ratio = \"\>", "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Mass ratio = ", 0.01, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238407833*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"54b5473f-e091-48f8-a2c7-2b2eee335976"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Lagrangian Point \"\>", "\[InvisibleSpace]", "1", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Lagrangian Point ", 1, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.8111672384088697`*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"dc81ea74-3264-47e6-9116-89feb7c4d865"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{x0, y0} = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.8480787129760952`", ",", "0"}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["{x0, y0} = ", {0.8480787129760952, 0}, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238409492*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"995a4fc6-5d2d-4935-b106-f16da97c06fa"],

Cell[BoxData["\<\"Eigenvalues :\"\>"], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238410033*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"c1c4356b-75b9-49a8-94be-6a94ea901e9a"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   InterpretationBox[GridBox[{
      {
       RowBox[{"-", "2.903737831611213`"}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"2.316558990002522`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"2.316558990002522`", " ", "\[ImaginaryI]"}]}]},
      {"2.903737831611213`"}
     },
     BaselinePosition->{Baseline, {1, 1}},
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
    ColumnForm[{-2.903737831611213, 
      Complex[0., -2.316558990002522], 
      Complex[0., 2.316558990002522], 2.903737831611213}],
    Editable->False], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
   ColumnForm[{-2.903737831611213, 
     Complex[0., -2.316558990002522], 
     Complex[0., 2.316558990002522], 2.903737831611213}], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238410708*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"facc2b5e-0d20-48d7-934c-c974e4705925"],

Cell[BoxData["\<\"\\nValues of \[Alpha] bar: \"\>"], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.8111672384115887`*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"32ba3fcd-26d6-4ac2-951c-3e5fd6caa636"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"6.992592099954357`*^-6"},
    {
     RowBox[{
      RowBox[{"-", "9.779588016918605`*^-7"}], "+", 
      RowBox[{"1.2718126782405257`*^-6", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "9.779588016918605`*^-7"}], "-", 
      RowBox[{"1.2718126782405257`*^-6", " ", "\[ImaginaryI]"}]}]},
    {"4.963325503429365`*^-6"}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{6.992592099954357*^-6, 
    Complex[-9.779588016918605*^-7, 1.2718126782405257`*^-6], 
    Complex[-9.779588016918605*^-7, -1.2718126782405257`*^-6], 
    4.963325503429365*^-6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.81116723841224*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"fa69ecb2-1c8f-4786-bc7b-efb141c20335"],

Cell[BoxData["\<\"\\nValues of \[Beta] bar: \"\>"], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238412969*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"ddb283d0-1439-4192-b03a-f6dfcb1086b6"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"3.249539841687121`*^-6"},
    {
     RowBox[{"4.528487965510255`*^-6", "+", 
      RowBox[{"3.4821752762782795`*^-6", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"4.528487965510255`*^-6", "-", 
      RowBox[{"3.4821752762782795`*^-6", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"-", "2.3065157727076324`*^-6"}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{3.249539841687121*^-6, 
    Complex[4.528487965510255*^-6, 3.4821752762782795`*^-6], 
    Complex[
    4.528487965510255*^-6, -3.4821752762782795`*^-6], \
-2.3065157727076324`*^-6}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238413604*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"b970650a-90a0-4423-a381-f01e619d7841"],

Cell[BoxData["\<\"\\nX(t) = \"\>"], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.8111672384143143`*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"2427f9a9-7952-4b8c-9534-edfa7f73b86b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"6.992592099954357`*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.903737831611213`"}], " ", "t"}]]}], "+", 
  RowBox[{"4.963325503429365`*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{"2.903737831611213`", " ", "t"}]]}], "-", 
  RowBox[{"1.955917603383721`*^-6", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"2.316558990002522`", " ", "t"}], "]"}]}], "+", 
  RowBox[{"2.5436253564810514`*^-6", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"2.316558990002522`", " ", "t"}], "]"}]}]}]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238414959*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"4f855d4f-4b17-42f8-917e-62e163995090"],

Cell[BoxData["\<\"\\nY(t) = \"\>"], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238415635*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"ee4bdd96-2b1d-41b9-aafd-e893368f0d1b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"3.249539841687121`*^-6", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "2.903737831611213`"}], " ", "t"}]]}], "-", 
    RowBox[{"2.3065157727076324`*^-6", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"2.903737831611213`", " ", "t"}]]}], "+", 
    RowBox[{"9.05697593102051`*^-6", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"2.316558990002522`", " ", "t"}], "]"}]}], "+", 
    RowBox[{"6.964350552556559`*^-6", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"2.316558990002522`", " ", "t"}], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
  3.249539841687121*^-6 E^((-2.903737831611213) $CellContext`t) - 
   2.3065157727076324`*^-6 E^(2.903737831611213 $CellContext`t) + 
   9.05697593102051*^-6 Cos[2.316558990002522 $CellContext`t] + 
   6.964350552556559*^-6 Sin[2.316558990002522 $CellContext`t], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.81116696398701*^9, 3.811167109788731*^9, {3.811167176037163*^9, 
   3.811167238416363*^9}},
 CellLabel->
  "During evaluation of \
In[2]:=",ExpressionUUID->"637ef6d6-2b66-4a84-aa85-092518873572"]
}, Open  ]],

Cell["\<\
In the second example we examine the stability of the L4 point for a mass \
ratio \[Mu]=0.01 and small displacement of (0.00001,0.00001) from the \
equilibrium point.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"df24519b-affe-4b02-9b0d-2ea61c328055"],

Cell[CellGroupData[{

Cell["Stability[0.01, 4, {0.00001,0.00001}]", "Input",
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"In[3]:=",ExpressionUUID->"3c61dc84-b1e2-4cfd-a8f7-96545efe4ec3"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Mass ratio = \"\>", "\[InvisibleSpace]", "0.01`", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Mass ratio = ", 0.01, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238421422*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"c52ed35d-baa2-4516-9b21-1e668989187b"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Lagrangian Point \"\>", "\[InvisibleSpace]", "4", 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["Lagrangian Point ", 4, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.81116723842212*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"20b6b4a5-b986-4632-96d5-e3a92d6ce116"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"{x0, y0} = \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"0.49`", ",", "0.8660254037844386`"}], "}"}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm["{x0, y0} = ", {0.49, 0.8660254037844386}, "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.8111672384226933`*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"1dca9d6e-44f3-4756-9ac2-396023b4e7c2"],

Cell[BoxData["\<\"Eigenvalues :\"\>"], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238423259*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"fd2252d8-3001-4c0f-b800-631f3e32a192"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   InterpretationBox[GridBox[{
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.26834774854251275`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.26834774854251275`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "-", 
        RowBox[{"0.9633221090850995`", " ", "\[ImaginaryI]"}]}]},
      {
       RowBox[{"0.`", "\[VeryThinSpace]", "+", 
        RowBox[{"0.9633221090850995`", " ", "\[ImaginaryI]"}]}]}
     },
     BaselinePosition->{Baseline, {1, 1}},
     GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
    ColumnForm[{
      Complex[0., -0.26834774854251275`], 
      Complex[0., 0.26834774854251275`], 
      Complex[0., -0.9633221090850995], 
      Complex[0., 0.9633221090850995]}],
    Editable->False], "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
   ColumnForm[{
     Complex[0., -0.26834774854251275`], 
     Complex[0., 0.26834774854251275`], 
     Complex[0., -0.9633221090850995], 
     Complex[0., 0.9633221090850995]}], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238423983*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"bc21a36a-f217-4b35-91e2-1a2e450c445b"],

Cell[BoxData["\<\"\\nValues of \[Alpha] bar: \"\>"], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.8111672384247513`*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"c5063c49-0775-403e-aa3c-a50c743722cb"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{"0.000017237846529918217`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00015337644256131216`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"0.00001723784652991825`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.00015337644256131213`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.00001223784652991822`"}], "-", 
      RowBox[{"0.00004272529681673925`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000012237846529918234`"}], "+", 
      RowBox[{"0.000042725296816739246`", " ", "\[ImaginaryI]"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{
    Complex[0.000017237846529918217`, 0.00015337644256131216`], 
    Complex[0.00001723784652991825, -0.00015337644256131213`], 
    Complex[-0.00001223784652991822, -0.00004272529681673925], 
    Complex[-0.000012237846529918234`, 0.000042725296816739246`]}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238425452*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"43723e4d-a641-4c42-9ab2-6f82d8e82352"],

Cell[BoxData["\<\"\\nValues of \[Beta] bar: \"\>"], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.8111672384262457`*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"9213a0eb-4058-4d40-858d-668bf8144a41"],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {
     RowBox[{"0.000025999744015632008`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.00008807388248169476`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{"0.00002599974401563198`", "\[VeryThinSpace]", "+", 
      RowBox[{"0.00008807388248169474`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000020999744015632002`"}], "+", 
      RowBox[{"0.000024534294237061656`", " ", "\[ImaginaryI]"}]}]},
    {
     RowBox[{
      RowBox[{"-", "0.000020999744015631988`"}], "-", 
      RowBox[{"0.00002453429423706166`", " ", "\[ImaginaryI]"}]}]}
   },
   BaselinePosition->{Baseline, {1, 1}},
   GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}],
  ColumnForm[{
    Complex[0.000025999744015632008`, -0.00008807388248169476], 
    Complex[0.00002599974401563198, 0.00008807388248169474], 
    Complex[-0.000020999744015632002`, 0.000024534294237061656`], 
    Complex[-0.000020999744015631988`, -0.00002453429423706166]}],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238426989*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"dee4797c-400a-49e7-a4eb-b8352b87e40f"],

Cell[BoxData["\<\"\\nX(t) = \"\>"], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.8111672384276857`*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"2191494c-76ac-485e-ae02-38e7eadd232a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.00003447569305983647`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
  RowBox[{"0.000024475693059836455`", " ", 
   RowBox[{"Cos", "[", 
    RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "+", 
  RowBox[{"0.00030675288512262426`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
  RowBox[{"0.00008545059363347849`", " ", 
   RowBox[{"Sin", "[", 
    RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.81116723842829*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"56fe5e09-c65f-46be-9492-be361d454b54"],

Cell[BoxData["\<\"\\nY(t) = \"\>"], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238428853*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"eb06d396-6ac4-4287-9fb2-351c7bf1d204"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   RowBox[{
    RowBox[{"0.00005199948803126399`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00004199948803126399`", " ", 
     RowBox[{"Cos", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}], "-", 
    RowBox[{"0.00017614776496338949`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.26834774854251275`", " ", "t"}], "]"}]}], "+", 
    RowBox[{"0.00004906858847412331`", " ", 
     RowBox[{"Sin", "[", 
      RowBox[{"0.9633221090850995`", " ", "t"}], "]"}]}]}], 
   "\[InvisibleSpace]", "\<\"\\n\"\>"}],
  SequenceForm[
  0.00005199948803126399 Cos[0.26834774854251275` $CellContext`t] - 
   0.00004199948803126399 Cos[0.9633221090850995 $CellContext`t] - 
   0.00017614776496338949` Sin[0.26834774854251275` $CellContext`t] + 
   0.00004906858847412331 Sin[0.9633221090850995 $CellContext`t], "\n"],
  Editable->False]], "Print",
 CellChangeTimes->{
  3.811166964013543*^9, 3.811167109842731*^9, {3.8111671760695143`*^9, 
   3.811167238429509*^9}},
 CellLabel->
  "During evaluation of \
In[3]:=",ExpressionUUID->"0ede7055-0aac-45b0-8304-45acfdb86e7d"]
}, Open  ]]
},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{916, 829},
WindowMargins->{{17, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"12.1 for Mac OS X x86 (64-bit) (June 19, 2020)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"5927bec7-8cfd-4fad-a1a0-282d5ef97388"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 96, 0, 67, "Section",ExpressionUUID->"91b05445-c52f-4009-bd5e-44984d393a60"],
Cell[657, 22, 783, 21, 118, "Text",ExpressionUUID->"a2dd74a2-23ad-4b70-a9ff-8c1d2c4e6166"],
Cell[1443, 45, 2907, 82, 1380, "Input",ExpressionUUID->"4e73d262-3ac7-4d62-920c-b57f37a4ee71"],
Cell[4353, 129, 399, 8, 163, "Text",ExpressionUUID->"6a3b16f9-ce5c-4575-b76e-fd643a793d2f"],
Cell[CellGroupData[{
Cell[4777, 141, 164, 2, 30, "Input",ExpressionUUID->"6ff58bb2-071a-4adc-aae2-4db1ae0d6831"],
Cell[4944, 145, 435, 11, 44, "Print",ExpressionUUID->"54b5473f-e091-48f8-a2c7-2b2eee335976"],
Cell[5382, 158, 438, 11, 44, "Print",ExpressionUUID->"dc81ea74-3264-47e6-9116-89feb7c4d865"],
Cell[5823, 171, 513, 13, 44, "Print",ExpressionUUID->"995a4fc6-5d2d-4935-b106-f16da97c06fa"],
Cell[6339, 186, 267, 6, 24, "Print",ExpressionUUID->"c1c4356b-75b9-49a8-94be-6a94ea901e9a"],
Cell[6609, 194, 1125, 30, 102, "Print",ExpressionUUID->"facc2b5e-0d20-48d7-934c-c974e4705925"],
Cell[7737, 226, 283, 6, 44, "Print",ExpressionUUID->"32ba3fcd-26d6-4ac2-951c-3e5fd6caa636"],
Cell[8023, 234, 948, 25, 82, "Print",ExpressionUUID->"fa69ecb2-1c8f-4786-bc7b-efb141c20335"],
Cell[8974, 261, 280, 6, 44, "Print",ExpressionUUID->"ddb283d0-1439-4192-b03a-f6dfcb1086b6"],
Cell[9257, 269, 930, 25, 82, "Print",ExpressionUUID->"b970650a-90a0-4423-a381-f01e619d7841"],
Cell[10190, 296, 266, 6, 44, "Print",ExpressionUUID->"2427f9a9-7952-4b8c-9534-edfa7f73b86b"],
Cell[10459, 304, 795, 20, 25, "Print",ExpressionUUID->"4f855d4f-4b17-42f8-917e-62e163995090"],
Cell[11257, 326, 264, 6, 44, "Print",ExpressionUUID->"ee4bdd96-2b1d-41b9-aafd-e893368f0d1b"],
Cell[11524, 334, 1201, 29, 45, "Print",ExpressionUUID->"637ef6d6-2b66-4a84-aa85-092518873572"]
}, Open  ]],
Cell[12740, 366, 300, 7, 76, "Text",ExpressionUUID->"df24519b-affe-4b02-9b0d-2ea61c328055"],
Cell[CellGroupData[{
Cell[13065, 377, 164, 2, 30, "Input",ExpressionUUID->"3c61dc84-b1e2-4cfd-a8f7-96545efe4ec3"],
Cell[13232, 381, 438, 11, 44, "Print",ExpressionUUID->"c52ed35d-baa2-4516-9b21-1e668989187b"],
Cell[13673, 394, 438, 11, 44, "Print",ExpressionUUID->"20b6b4a5-b986-4632-96d5-e3a92d6ce116"],
Cell[14114, 407, 525, 13, 44, "Print",ExpressionUUID->"1dca9d6e-44f3-4756-9ac2-396023b4e7c2"],
Cell[14642, 422, 270, 6, 24, "Print",ExpressionUUID->"fd2252d8-3001-4c0f-b800-631f3e32a192"],
Cell[14915, 430, 1387, 37, 102, "Print",ExpressionUUID->"bc21a36a-f217-4b35-91e2-1a2e450c445b"],
Cell[16305, 469, 286, 6, 44, "Print",ExpressionUUID->"c5063c49-0775-403e-aa3c-a50c743722cb"],
Cell[16594, 477, 1255, 30, 76, "Print",ExpressionUUID->"43723e4d-a641-4c42-9ab2-6f82d8e82352"],
Cell[17852, 509, 285, 6, 44, "Print",ExpressionUUID->"9213a0eb-4058-4d40-858d-668bf8144a41"],
Cell[18140, 517, 1256, 30, 76, "Print",ExpressionUUID->"dee4797c-400a-49e7-a4eb-b8352b87e40f"],
Cell[19399, 549, 269, 6, 44, "Print",ExpressionUUID->"2191494c-76ac-485e-ae02-38e7eadd232a"],
Cell[19671, 557, 770, 19, 24, "Print",ExpressionUUID->"56fe5e09-c65f-46be-9492-be361d454b54"],
Cell[20444, 578, 267, 6, 44, "Print",ExpressionUUID->"eb06d396-6ac4-4287-9fb2-351c7bf1d204"],
Cell[20714, 586, 1186, 28, 44, "Print",ExpressionUUID->"0ede7055-0aac-45b0-8304-45acfdb86e7d"]
}, Open  ]]
}
]
*)

(* End of internal cache information *)

